import { CircuitId } from '../../circuits';
import { DID } from '@iden3/js-iden3-core';
import { IProofService } from '../../proof';
import { ZeroKnowledgeProofResponse } from '../types';
import { ProofData } from '@iden3/js-jwz';
/**
 * @beta
 * Retrieves the request ID from circuit string.
 * CircuitId.AuthV2 - 940499666
 * @returns The request ID.
 */
export declare function calculateRequestIdForCircuit(circuitId: CircuitId): number;
/**
 * Prepares the zero-knowledge proof response for the AuthV2 circuit.
 * @beta
 * @param address - The address associated with the request.
 * @param senderDid - The sender's decentralized identifier (DID).
 * @param proofService - The proof service used to generate the proof.
 * @returns A promise that resolves to an array of ZeroKnowledgeProofResponse objects.
 */
export declare function prepareAuthV2ZeroKnowledgeResponse(address: string, senderDid: DID, proofService: IProofService): Promise<ZeroKnowledgeProofResponse[]>;
export declare const packZkpProof: (inputs: string[], a: string[], b: string[][], c: string[]) => string;
export declare const prepareZkpProof: (proof: ProofData) => {
    a: string[];
    b: string[][];
    c: string[];
};
