import { RootInfo, StateProof } from './../entities/state';
import { ZKProof } from '@iden3/js-jwz';
import { IStateStorage, UserStateTransitionInfo } from '../interfaces/state';
import { Contract, JsonRpcProvider, Signer } from 'ethers';
import { StateInfo } from '../entities/state';
/**
 * Configuration of ethereum based blockchain connection
 *
 * @public
 * @interface   EthConnectionConfig
 */
export interface EthConnectionConfig {
    url: string;
    defaultGasLimit: number;
    minGasPrice?: string;
    maxGasPrice?: string;
    maxFeePerGas?: string;
    maxPriorityFeePerGas?: string;
    confirmationBlockCount: number;
    confirmationTimeout: number;
    contractAddress: string;
    receiptTimeout: number;
    rpcResponseTimeout: number;
    waitReceiptCycleTime: number;
    waitBlockCycleTime: number;
    chainId?: number;
}
export declare const defaultEthConnectionConfig: EthConnectionConfig;
/**
 *
 *
 * @public
 * @class EthStateStorage
 * @implements implements IStateStorage interface
 */
export declare class EthStateStorage implements IStateStorage {
    private readonly ethConfig;
    readonly stateContract: Contract;
    private readonly provider;
    private readonly _transactionService;
    /**
     * Creates an instance of EthStateStorage.
     * @param {EthConnectionConfig} [ethConfig=defaultEthConnectionConfig]
     */
    constructor(ethConfig: EthConnectionConfig | EthConnectionConfig[]);
    /** {@inheritdoc IStateStorage.getLatestStateById} */
    getLatestStateById(id: bigint): Promise<StateInfo>;
    /** {@inheritdoc IStateStorage.getStateInfoByIdAndState} */
    getStateInfoByIdAndState(id: bigint, state: bigint): Promise<StateInfo>;
    /** {@inheritdoc IStateStorage.publishState} */
    publishState(proof: ZKProof, signer: Signer): Promise<string>;
    /** {@inheritdoc IStateStorage.publishStateGeneric} */
    publishStateGeneric(signer: Signer, userStateTransitionInfo: UserStateTransitionInfo): Promise<string>;
    /** {@inheritdoc IStateStorage.getGISTProof} */
    getGISTProof(id: bigint): Promise<StateProof>;
    /** {@inheritdoc IStateStorage.getGISTRootInfo} */
    getGISTRootInfo(root: bigint, id: bigint): Promise<RootInfo>;
    /** {@inheritdoc IStateStorage.getRpcProvider} */
    getRpcProvider(): JsonRpcProvider;
    private getStateContractAndProviderForId;
    private networkByChainId;
}
