/** DIDDocumentJSONSchema is a basic schema of did document */
export declare const DIDDocumentJSONSchema = "{\n  \"type\": \"object\",\n  \"$defs\": {\n    \"serviceEndpoint\": {\n      \"type\": \"object\",\n      \"properties\": {\n        \"id\": {\n          \"type\": \"string\"\n        },\n        \"type\": {\n          \"type\": \"string\"\n        },\n        \"serviceEndpoint\": {\n          \"type\": \"string\"\n        },\n        \"metadata\": {\n          \"type\": \"object\"\n        }\n      },\n      \"required\": [\n        \"id\",\n        \"type\",\n        \"serviceEndpoint\"\n      ]\n    },\n    \"jsonWebKey\": {\n      \"type\": \"object\",\n      \"properties\": {\n        \"alg\": {\n          \"type\": \"string\"\n        },\n        \"crv\": {\n          \"type\": \"string\"\n        },\n        \"e\": {\n          \"type\": \"string\"\n        },\n        \"ext\": {\n          \"type\": \"boolean\"\n        },\n        \"key_ops\": {\n          \"type\": \"array\",\n          \"items\": {\n            \"type\": \"string\"\n          }\n        },\n        \"kid\": {\n          \"type\": \"string\"\n        },\n        \"kty\": {\n          \"type\": \"string\"\n        },\n        \"n\": {\n          \"type\": \"string\"\n        },\n        \"use\": {\n          \"type\": \"string\"\n        },\n        \"x\": {\n          \"type\": \"string\"\n        },\n        \"y\": {\n          \"type\": \"string\"\n        }\n      },\n      \"required\": [\n        \"kty\"\n      ],\n      \"description\": \"Public parts of JSON web key\"\n    },\n    \"verificationMethod\": {\n      \"type\": \"object\",\n      \"properties\": {\n        \"id\": {\n          \"type\": \"string\"\n        },\n        \"type\": {\n          \"type\": \"string\"\n        },\n        \"controller\": {\n          \"type\": \"string\"\n        },\n        \"publicKeyBase58\": {\n          \"type\": \"string\"\n        },\n        \"publicKeyBase64\": {\n          \"type\": \"string\"\n        },\n        \"publicKeyJwk\": {\n          \"$ref\": \"#/$defs/jsonWebKey\"\n        },\n        \"publicKeyHex\": {\n          \"type\": \"string\"\n        },\n        \"publicKeyMultibase\": {\n          \"type\": \"string\"\n        },\n        \"blockchainAccountId\": {\n          \"type\": \"string\"\n        },\n        \"ethereumAddress\": {\n          \"type\": \"string\"\n        }\n      },\n      \"required\": [\n        \"id\",\n        \"type\",\n        \"controller\"\n      ]\n    }\n  },\n  \"properties\": {\n    \"authentication\": {\n      \"type\": \"array\",\n      \"items\": {\n        \"anyOf\": [\n          {\n            \"type\": \"string\"\n          },\n          {\n            \"$ref\": \"#/$defs/verificationMethod\"\n          }\n        ]\n      }\n    },\n    \"assertionMethod\": {\n      \"type\": \"array\",\n      \"items\": {\n        \"anyOf\": [\n          {\n            \"type\": \"string\"\n          },\n          {\n            \"$ref\": \"#/$defs/verificationMethod\"\n          }\n        ]\n      }\n    },\n    \"keyAgreement\": {\n      \"type\": \"array\",\n      \"items\": {\n        \"anyOf\": [\n          {\n            \"type\": \"string\"\n          },\n          {\n            \"$ref\": \"#/$defs/verificationMethod\"\n          }\n        ]\n      }\n    },\n    \"capabilityInvocation\": {\n      \"type\": \"array\",\n      \"items\": {\n        \"anyOf\": [\n          {\n            \"type\": \"string\"\n          },\n          {\n            \"$ref\": \"#/$defs/verificationMethod\"\n          }\n        ]\n      }\n    },\n    \"capabilityDelegation\": {\n      \"type\": \"array\",\n      \"items\": {\n        \"anyOf\": [\n          {\n            \"type\": \"string\"\n          },\n          {\n            \"$ref\": \"#/$defs/verificationMethod\"\n          }\n        ]\n      }\n    },\n    \"@context\": {\n      \"anyOf\": [\n        {\n          \"type\": \"string\",\n          \"const\": \"https://www.w3.org/ns/did/v1\"\n        },\n        {\n          \"type\": \"string\"\n        },\n        {\n          \"type\": \"array\",\n          \"items\": {\n            \"type\": \"string\"\n          }\n        }\n      ]\n    },\n    \"id\": {\n      \"type\": \"string\"\n    },\n    \"alsoKnownAs\": {\n      \"type\": \"array\",\n      \"items\": {\n        \"type\": \"string\"\n      }\n    },\n    \"controller\": {\n      \"anyOf\": [\n        {\n          \"type\": \"string\"\n        },\n        {\n          \"type\": \"array\",\n          \"items\": {\n            \"type\": \"string\"\n          }\n        }\n      ]\n    },\n    \"verificationMethod\": {\n      \"type\": \"array\",\n      \"items\": {\n        \"$ref\": \"#/$defs/verificationMethod\"\n      }\n    },\n    \"service\": {\n      \"type\": \"array\",\n      \"items\": {\n        \"$ref\": \"#/$defs/serviceEndpoint\"\n      }\n    },\n    \"publicKey\": {\n      \"type\": \"array\",\n      \"items\": {\n        \"$ref\": \"#/$defs/verificationMethod\"\n      },\n      \"deprecated\": true\n    }\n  },\n  \"required\": [\n    \"id\"\n  ]\n}";
